-- $Id: functions.sql,v 1.4 2002/01/09 23:14:14 ciaccia Exp $

-- Drop existing functions

DROP FUNCTION unix_timestamp(timestamp);
DROP FUNCTION from_unixtime(int4);
DROP FUNCTION to_days(timestamp);
DROP FUNCTION dayofmonth(timestamp);
DROP FUNCTION month(timestamp);
DROP FUNCTION year(timestamp);
DROP FUNCTION week(timestamp);
DROP FUNCTION hour(timestamp);
DROP FUNCTION date_format(timestamp, text);
DROP FUNCTION if(bool, varchar, varchar);
DROP FUNCTION phpads_ww(int, timestamp);
DROP FUNCTION phpads_yyyy(int, timestamp);


-- MySQL compatibility functions

BEGIN;

CREATE FUNCTION unix_timestamp(timestamp) RETURNS int8 AS
'SELECT (CASE WHEN $1 = NULL THEN 0 ELSE date_part(\'epoch\', $1) END)::int8' LANGUAGE 'sql';

CREATE FUNCTION from_unixtime(int4) RETURNS timestamp AS
'SELECT \'1970-01-01 00:00:00\'::timestamp + ($1 || \' seconds\')::interval' LANGUAGE 'sql';

CREATE FUNCTION to_days(timestamp) RETURNS int8 AS
'SELECT floor(CASE WHEN $1 = NULL THEN 0 ELSE unix_timestamp($1)/86400 END)::int8' LANGUAGE 'sql';

CREATE FUNCTION dayofmonth(timestamp) RETURNS int2 AS
'SELECT date_part(\'day\', $1)::int2' LANGUAGE 'sql';

CREATE FUNCTION month(timestamp) RETURNS int2 AS
'SELECT date_part(\'month\', $1)::int2' LANGUAGE 'sql';

CREATE FUNCTION year(timestamp) RETURNS int4 AS
'SELECT date_part(\'year\', $1)::int4' LANGUAGE 'sql';

CREATE FUNCTION week(timestamp) RETURNS int2 AS
'SELECT date_part(\'week\', $1)::int2' LANGUAGE 'sql';

CREATE FUNCTION hour(timestamp) RETURNS int2 AS
'SELECT date_part(\'hour\', $1)::int2' LANGUAGE 'sql';

CREATE FUNCTION date_format(timestamp, text) RETURNS text AS
'SELECT CASE WHEN $1 = NULL THEN \'\' ELSE to_char($1, $2) END' LANGUAGE 'sql';

CREATE FUNCTION if(bool, varchar, varchar) RETURNS varchar AS
'SELECT CASE WHEN $1 THEN $2 ELSE $3 END' LANGUAGE 'sql';

-- ISO week functions

CREATE FUNCTION phpads_ww(int, timestamp) RETURNS text AS
'SELECT to_char(week($2 + ((1 - $1) || \' day\')::interval)::int, \'FM00\'::text)' LANGUAGE 'sql';

CREATE FUNCTION phpads_yyyy(int, timestamp) RETURNS text AS '
SELECT CASE
WHEN week($2 + ((1 - $1) || \' day\')::interval) >= 52 AND month($2) = 1 THEN to_char(year($2)-1, \'FM0000\')
WHEN week($2 + ((1 - $1) || \' day\')::interval) = 1 AND month($2) = 12 THEN to_char(year($2)+1, \'FM0000\')
ELSE to_char(year($2), \'FM0000\')
END
' LANGUAGE 'sql';

COMMIT;
